@@ -35,13 +35,12 @@ NULL
 
 #' @references
 #' \cite{Abadie, Alberto (2005), "Semiparametric Difference-in-Differences Estimators",
-#' Review of Economic Studies, vol. 72(1), p. 1-19, \url{https://doi.org/10.1111/0034-6527.00321}.
-#' }
+#' Review of Economic Studies, vol. 72(1), p. 1-19, \doi{10.1111/0034-6527.00321}}
 #'
 #'
 #' \cite{Sant'Anna, Pedro H. C. and Zhao, Jun. (2020),
-#' "Doubly Robust Difference-in-Differences Estimators." Journal of Econometrics, Forthcoming,
-#' \url{https://arxiv.org/abs/1812.01723}}
+#' "Doubly Robust Difference-in-Differences Estimators." Journal of Econometrics, Vol. 219 (1), pp. 101-122,
+#' \doi{10.1016/j.jeconom.2020.06.003}}
 #'
 #'
 #' @examples
@@ -88,6 +87,12 @@ ipw_did_panel <-function(y1, y0, D, covariates, i.weights = NULL,
   #-----------------------------------------------------------------------------
   #Pscore estimation (logit) and also its fitted values
   PS <- suppressWarnings(stats::glm(D ~ -1 + int.cov, family = "binomial", weights = i.weights))
+  if(PS$converged == FALSE){
+    warning(" glm algorithm did not converge")
+  }
+  if(anyNA(PS$coefficients)){
+    stop("Propensity score model coefficients have NA components. \n Multicollinearity (or lack of variation) of covariates is a likely reason.")
+  }
   ps.fit <- as.vector(PS$fitted.values)
   # Do not divide by zero
   ps.fit <- pmin(ps.fit, 1 - 1e-16)
